local urfs = require "urfs"

local license
local position_x, position_y = 0, 0

function love.load()
  love.window.setTitle("LÖVE License")
  local major, minor, revision, codename = love.getVersion()
  local loveVersion = string.format("Version %d.%d.%d - %s", major, minor, revision, codename)
  local loveOS = love.system.getOS()
  print("Runtime: LÖVE " .. loveVersion .. " on " .. loveOS)
  print("API version: " .. _VERSION)
  print(jit.version .. " on " .. jit.os .. " (" .. jit.arch .. ")")

  local pathSeparator = (loveOS == "Windows") and "\\" or "/"
  local luaExtension = ".lua"
  local moduleExtension = (loveOS == "Windows") and ".dll" or ".so"
  local exeExtension = (loveOS == "Windows") and ".exe" or ""

  local executablePath = arg[-2]
  local executableDir = executablePath:match("(.*" .. pathSeparator .. ")")
  local executableName = executablePath:match("([^" .. pathSeparator .. "]+)$")

  local licenseDir = executableDir
  if loveOS ~= "Windows" then
    licenseDir = licenseDir .. ((loveOS == "OS X") and "../Resources/" or "../")
  end
  local licenseFile = "license.txt"

  local pathTable = {}
  for path in package.path:gmatch("[^;]+") do
    table.insert(pathTable, path)
  end

  local cpathTable = {}
  for cpath in package.cpath:gmatch("[^;]+") do
    table.insert(cpathTable, cpath)
  end

  urfs.mount(licenseDir)
  print("Loading " .. love.filesystem.getRealDirectory(licenseFile) .. licenseFile)
  local fileInfo = love.filesystem.getInfo(licenseFile)
  if fileInfo then
    license, size = love.filesystem.read(licenseFile)
    if not license then
      license = "Failed to load license: " .. size
    end
  else
      license = "License file not found"
  end
  urfs.unmount(licenseDir)
end

function love.draw()
  love.graphics.print(license, position_x, position_y)
end

function love.wheelmoved(x, y)
  position_x = position_x + x * 10
  position_y = position_y + y * 10
end